@@ -11,9 +11,9 @@ class TestUserWithResources(HttpUserWithResources):
         self.client.get("/cart.html")
 
     @task
-    def include_resources_true(self):
+    def include_resources_with_specific_filter(self):
         self.client.get("/", resource_filter=".*[^(js)]$")
 
     @task
-    def include_resources_false(self):
+    def include_no_resources(self):
         self.client.get("/index.html", include_resources=False)
