@@ -1,20 +1,18 @@
 from .wait_time import constant_ips, constant_total_ips
-from .debug import run_single_user
 from .listeners import Timescale
 import locust
-from locust import TaskSet
-from locust.user.task import DefaultTaskSet
+from locust.user.task import DefaultTaskSet, TaskSet
 from locust import events
 from locust.exception import StopUser
 from locust.env import Environment
+from locust.argument_parser import LocustArgumentParser
 from locust.runners import Runner, WorkerRunner
 import logging
 from functools import wraps
-import configargparse
 
 
 @events.init_command_line_parser.add_listener
-def add_checks_arguments(parser: configargparse.ArgumentParser):
+def add_arguments(parser: LocustArgumentParser):
     checks = parser.add_argument_group(
         "locust-plugins - Checks",
         "Sets locust's exit code to 3 if any of these thresholds were not met",
@@ -104,6 +102,13 @@ def add_checks_arguments(parser: configargparse.ArgumentParser):
         env_var="LOCUST_TEST_ENV",
         default="",
     )
+    run_info.add_argument(
+        "--profile",
+        type=str,
+        help="Load profile (a user-configurable string, like any config value it can be accessed using environment.parsed_options.profile)",
+        env_var="LOCUST_PROFILE",
+        default="",
+    )
     run_info.add_argument(
         "--test-version",
         type=str,
@@ -118,13 +123,6 @@ def add_checks_arguments(parser: configargparse.ArgumentParser):
         default="",
         help="Description of the test being run",
     )
-    run_info.add_argument(
-        "--run-id",
-        type=str,
-        help=configargparse.SUPPRESS,  # generated by locust-swarm
-        env_var="LOCUST_RUN_ID",
-        default="",
-    )
     run_info.add_argument(
         "--override-plan-name",
         type=str,
@@ -140,7 +138,7 @@ def add_checks_arguments(parser: configargparse.ArgumentParser):
         "-i",
         "--iterations",
         type=int,
-        help="Dont run more than this number of task iterations and terminate once they have finished",
+        help="Run at most this number of task iterations and terminate once they have finished",
         env_var="LOCUST_ITERATIONS",
         default=0,
     )
@@ -180,6 +178,7 @@ def set_up_iteration_limit(environment: Environment, **kwargs):
         runner: Runner = environment.runner
         runner.iterations_started = 0
         runner.iteration_target_reached = False
+        logging.debug(f"Iteration limit set to {options.iterations}")
 
         def iteration_limit_wrapper(method):
             @wraps(method)
