@@ -5,8 +5,11 @@ from locust.exception import (
     CatchResponseError,
     InterruptTaskSet,
 )  # need to do this first to make sure monkey patching is done
+import locust.env
 import gevent
+from gevent.lock import Semaphore
 import psycogreen.gevent
+
 import json
 
 psycogreen.gevent.patch_psycopg()
@@ -18,19 +21,17 @@ import os
 import socket
 import sys
 from datetime import datetime, timezone, timedelta
-
 import greenlet
-from dateutil import parser
-import subprocess
-import locust.env
 from typing import Callable, List
-from gevent.lock import Semaphore
+
 
 # pylint: disable=trailing-whitespace # pylint is confused by multiline strings used for SQL
 
 
 def safe_serialize(obj):
-    default = lambda o: f"<<non-serializable: {type(o).__qualname__}>>"
+    def default(o):
+        return f"<<non-serializable: {type(o).__qualname__}>>"
+
     return json.dumps(obj, default=default)
 
 
@@ -46,11 +47,7 @@ class Timescale:  # pylint: disable=R0902
     dblock = Semaphore()
     first_instance = True
 
-    def __init__(
-        self,
-        env: locust.env.Environment,
-        testplan: str = None,
-    ):
+    def __init__(self, env: locust.env.Environment, testplan: str = None):
         if not Timescale.first_instance:
             # we should refactor this into a module as it is much more pythonic
             raise Exception(
@@ -78,6 +75,13 @@ class Timescale:  # pylint: disable=R0902
         events.spawning_complete.add_listener(self.spawning_complete)
         atexit.register(self.log_stop_test_run)
 
+        if self.env.runner is not None:
+            self.env.runner.register_message("run_id", self.set_run_id)
+
+    def set_run_id(self, environment, msg, **kwargs):
+        logging.debug(f'Received run id from master. Using this {datetime.strptime(msg.data, "%Y-%m-%d, %H:%M:%S.%f")}')
+        self._run_id = datetime.strptime(msg.data, "%Y-%m-%d, %H:%M:%S.%f").astimezone(tz=timezone.utc)
+
     @contextmanager
     def dbcursor(self):
         with self.dblock:
@@ -102,39 +106,45 @@ class Timescale:  # pylint: disable=R0902
         with self.dbcursor() as cur:
             cur.execute("INSERT INTO events (time, text) VALUES (%s, %s)", (timestamp, message))
 
+    def set_gitrepo(self):
+        self._gitrepo = None
+        try:
+            path = os.getcwd()
+            while not self._gitrepo and len(path) > 4:
+                try:
+                    with open(path + "/.git/config", "r") as f:
+                        for l in f.readlines():
+                            l = l.strip()
+                            if l.startswith("url ="):
+                                self._gitrepo = l.split(":")[1][:-4]
+                                return
+                except FileNotFoundError:
+                    pass
+                path = os.path.abspath(os.path.dirname(path))
+        except:
+            pass  # probably on windows or something
+        logging.debug("couldnt figure out which git repo your locustfile is in")
+
     def on_start(self, environment: locust.env.Environment):
         try:
             self.dbconn = self._dbconn()
         except psycopg2.OperationalError as e:
             logging.error(e)
             sys.exit(1)
-        try:
-            self._gitrepo = subprocess.check_output(
-                "git remote show origin -n 2>/dev/null | grep h.URL | sed 's/.*://;s/.git$//' || true",
-                shell=True,
-                stderr=None,
-                universal_newlines=True,
-            )
-        except:
-            # happens on windows
-            self._gitrepo = None
+        self.set_gitrepo()
 
-        if is_worker() or is_master():
-            # swarm generates the run id for its master and workers
-            if getattr(environment.parsed_options, "run_id", False):
-                self._run_id = parser.parse(environment.parsed_options.run_id)
-            else:
-                logging.info(
-                    "You are running distributed, but without swarm. run_id:s in Timescale will not match exactly between load gens"
-                )
-                self._run_id = datetime.now(timezone.utc)
-        else:
-            # non-swarm runs need to generate the run id here
+        if not self.env.parsed_options.worker:
             self._run_id = datetime.now(timezone.utc)
-        if not is_worker():
             logging.info(
                 f"Follow test run here: {self.env.parsed_options.grafana_url}&var-testplan={self._testplan}&from={int(self._run_id.timestamp()*1000)}&to=now"
             )
+            msg = (
+                self._run_id.replace(tzinfo=timezone.utc)
+                .astimezone(tz=self._run_id.astimezone().tzinfo)
+                .strftime("%Y-%m-%d, %H:%M:%S.%f")
+            )
+            if environment.runner is not None:
+                environment.runner.send_message("run_id", msg)
             self.log_start_testrun()
             self._user_count_logger = gevent.spawn(self._log_user_count)
 
@@ -270,7 +280,7 @@ class Timescale:  # pylint: disable=R0902
         del cmd[0]
         with self.dbcursor() as cur:
             cur.execute(
-                "INSERT INTO testrun (id, testplan, num_clients, rps, description, env, username, gitrepo, changeset_guid, arguments) VALUES (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)",
+                "INSERT INTO testrun (id, testplan, num_clients, rps, description, env, profile_name, username, gitrepo, changeset_guid, arguments) VALUES (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)",
                 (
                     self._run_id,
                     self._testplan,
@@ -278,6 +288,7 @@ class Timescale:  # pylint: disable=R0902
                     self.env.parsed_options.ips,  # this field is incorrectly called "rps" in db, it should be called something like "target_ips"
                     self.env.parsed_options.description,
                     self.env.parsed_options.test_env,
+                    self.env.parsed_options.profile,
                     self._username,
                     self._gitrepo,
                     self.env.parsed_options.test_version,
@@ -290,7 +301,7 @@ class Timescale:  # pylint: disable=R0902
             )
 
     def spawning_complete(self, user_count):
-        if not is_worker():  # only log for master/standalone
+        if not self.env.parsed_options.worker:  # only log for master/standalone
             end_time = datetime.now(timezone.utc)
             try:
                 with self.dbcursor() as cur:
@@ -304,9 +315,9 @@ class Timescale:  # pylint: disable=R0902
                 )
 
     def log_stop_test_run(self, exit_code=None):
-        if is_worker():
+        if self.env.parsed_options.worker:
             return  # only run on master or standalone
-        if not self.dbconn:
+        if getattr(self, "dbconn", None) is None:
             return  # test_start never ran, so there's not much for us to do
         end_time = datetime.now(timezone.utc)
         try:
@@ -490,11 +501,3 @@ class RunOnUserError:
     def user_error(self, user_instance, exception, tb, **kwargs):
         if exception:
             self.function(user_instance, exception, tb, **kwargs)
-
-
-def is_worker():
-    return "--worker" in sys.argv
-
-
-def is_master():
-    return "--master" in sys.argv
