@@ -1,11 +1,12 @@
 from contextlib import contextmanager
-from locust.contrib.fasthttp import FastHttpUser
+from locust import FastHttpUser
 from locust.clients import ResponseContextManager
 import traceback
 import re
 from json.decoder import JSONDecodeError
 import autoviv
-from typing import Generator
+from typing import Generator, Optional
+import time
 
 
 class RestResponseContextManager(ResponseContextManager):
@@ -27,8 +28,10 @@ class RestUser(FastHttpUser):
     _callstack_regex = re.compile(r'  File "(\/.[^"]*)", line (\d*),(.*)')
 
     @contextmanager
-    def rest(self, method, url, **kwargs) -> Generator[RestResponseContextManager, None, None]:
-        headers = kwargs.pop("headers", {"Content-Type": "application/json", "Accept": "application/json"})
+    def rest(
+        self, method, url, headers: Optional[dict] = None, **kwargs
+    ) -> Generator[RestResponseContextManager, None, None]:
+        headers = {"Content-Type": "application/json", "Accept": "application/json"} if headers is None else headers
         with self.client.request(method, url, catch_response=True, headers=headers, **kwargs) as resp:
             resp: RestResponseContextManager
             resp.js = None
@@ -68,3 +71,9 @@ class RestUser(FastHttpUser):
                         error_lines.append(filename + ":" + m.group(2) + m.group(3))
                     short_resp = resp.text[:200] if resp.text else resp.text
                     resp.failure(f"{e.__class__.__name__}: {e} at {', '.join(error_lines)}. Response was {short_resp}")
+
+    # some web api:s use a timestamp as part of their url (to break thru caches). this is a convenience method for that.
+    @contextmanager
+    def rest_(self, method, url, name=None, **kwargs) -> ResponseContextManager:
+        with self.rest(method, f"{url}&_={int(time.time()*1000)}", name=name, **kwargs) as resp:
+            yield resp
